@@ -1,9 +1,9 @@
 package App::DuplicateFilesUtils;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-28'; # DATE
+our $DATE = '2020-06-01'; # DATE
 our $DIST = 'App-DuplicateFilesUtils'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -68,6 +68,15 @@ Sample output:
     | ./tmp/IMG_3430-(93).JPG      | 2190379 | 2     |
     +------------------------------+---------+-------+
 
+You can then delete or move the duplicates manually, if you want. But there's
+also <prog:move-duplicate-files-to> to automatically move all the duplicates
+(but one, for each set) to a directory of your choice.
+
+To perform other actions on the duplicate copies, for example delete them, you
+can use <prog:uniq-files> directly e.g. (in bash):
+
+    % uniq-files -R -D * | while read f; do rm "$p"; done
+
 _
     args => {
     },
@@ -91,6 +100,9 @@ $SPEC{move_duplicate_files_to} = {
     summary => 'Move duplicate files (except one copy) to a directory',
     description => <<'_',
 
+This utility will find all duplicate sets of files and move all of the
+duplicates (except one) for each set to a directory of your choosing.
+
 Moving is currently done using Perl's `rename()`, so files cannot be moved
 across filesystems.
 
@@ -173,7 +185,7 @@ App::DuplicateFilesUtils - CLI utilities related to duplicate files
 
 =head1 VERSION
 
-This document describes version 0.002 of App::DuplicateFilesUtils (from Perl distribution App-DuplicateFilesUtils), released on 2020-05-28.
+This document describes version 0.003 of App::DuplicateFilesUtils (from Perl distribution App-DuplicateFilesUtils), released on 2020-06-01.
 
 =head1 DESCRIPTION
 
@@ -198,6 +210,9 @@ Usage:
 
 Move duplicate files (except one copy) to a directory.
 
+This utility will find all duplicate sets of files and move all of the
+duplicates (except one) for each set to a directory of your choosing.
+
 Moving is currently done using Perl's C<rename()>, so files cannot be moved
 across filesystems.
 
@@ -297,6 +312,15 @@ Sample output:
  | ./tmp/IMG_3430-(93).JPG      | 2190379 | 2     |
  +------------------------------+---------+-------+
 
+You can then delete or move the duplicates manually, if you want. But there's
+also L<move-duplicate-files-to> to automatically move all the duplicates
+(but one, for each set) to a directory of your choice.
+
+To perform other actions on the duplicate copies, for example delete them, you
+can use L<uniq-files> directly e.g. (in bash):
+
+ % uniq-files -R -D * | while read f; do rm "$p"; done
+
 This function is not exported.
 
 No arguments.
